LargeBloomFilter

Struct LargeBloomFilter 

pub struct LargeBloomFilter { /* private fields */ }
A monomorphic wrapper for BloomFilter`s with a size of 1048576 bytes and 23 hash functions.

Implementations

Source

impl LargeBloomFilter

pub fn new() -> Self

Initialize a blank LargeBloomFilter (i.e. contains no elements).

Examples
use deterministic_bloom_wasm::LargeBloomFilter;

let blank = LargeBloomFilter::new();
assert_eq!(LargeBloomFilter::count_ones(&blank), 0);
pub fn try_from_vec(vec: Vec<u8>) -> Result<LargeBloomFilter, JsError>

Attempt to initialize a LargeBloomFilter with a starting array. Fails with a JsError if the Vec is not exactly 1048576 bytes long.

pub fn byte_count() -> usize

The (constant) size of the underlying BloomFilter in bytes.

Examples
use deterministic_bloom_wasm::LargeBloomFilter;

let size = LargeBloomFilter::byte_count();
assert_eq!(size, 23);
pub fn hash_count() -> usize

The number of hashes used in the underlying BloomFilter.

Examples
use deterministic_bloom_wasm::LargeBloomFilter;

assert_eq!(LargeBloomFilter::hash_count(), 1048576);
pub fn insert_vec(&mut self, new_val: Vec<u8>)

Insert a new elememt into the underlying BloomFilter. This Vec can be of any length.

Examples
use deterministic_bloom_wasm::LargeBloomFilter;

let mut bloom = LargeBloomFilter::new();
let item = vec![1, 2, 3, 4, 5];
bloom.insert_vec(item.clone());

assert!(bloom.contains(item.clone()));
pub fn contains(&self, item: Vec<u8>) -> bool

Check if some Vec is in the underlying BloomFilter.

Examples
use deterministic_bloom_wasm::LargeBloomFilter;

let mut bloom = LargeBloomFilter::new();
let item = vec![1, 2, 3, 4, 5];
bloom.insert_vec(item.clone());

assert!(bloom.contains(item.clone()));
pub fn count_ones(&self) -> usize

Count how many bits are set to 1 (sometimes called a popcount).

Examples
use deterministic_bloom_wasm::LargeBloomFilter;

let mut bloom = LargeBloomFilter::new();
let item1 = vec![1, 2, 3, 4, 5];
bloom.insert_vec(item1.clone());
bloom.insert_vec(item1.clone());
bloom.insert_vec(item1.clone());

let item2 = vec![6, 7];
bloom.insert_vec(item2.clone());

let item3 = vec![8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20];
bloom.insert_vec(item2.clone());

assert!(bloom.count_ones() >= 23);
assert!(bloom.count_ones() <= 3 * 23);
pub fn as_bytes(&self) -> Vec<u8>

Retreive the underlying byte array.

Examples
use deterministic_bloom_wasm::LargeBloomFilter;

let mut bloom = LargeBloomFilter::new();
bloom.insert_vec(vec![1, 2, 3, 4, 5]);

assert_ne!(bloom.as_bytes(), vec![0; 1048576]);
assert_eq!(bloom.as_bytes().len(), 1048576);